.. image:: https://jazzband.co/static/img/badge.svg
   :target: https://jazzband.co/
   :alt: Jazzband

.. image:: https://img.shields.io/pypi/v/wagtailmenus.svg
   :target: https://pypi.python.org/pypi/wagtailmenus
   :alt: PyPI Download

.. image:: https://img.shields.io/pypi/v/wagtailmenus.svg
    :alt: PyPi Version
    :target: https://pypi.python.org/pypi/wagtailmenus

.. image:: https://github.com/jazzband/wagtailmenus/actions/workflows/test.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/jazzband/wagtailmenus/actions/workflows/test.yml

.. image:: https://codecov.io/gh/jazzband/wagtailmenus/branch/master/graph/badge.svg
    :alt: Code coverage
    :target: https://codecov.io/gh/jazzband/wagtailmenus

.. image:: https://readthedocs.org/projects/wagtailmenus/badge/?version=latest
    :alt: Documentation Status
    :target: http://wagtailmenus.readthedocs.io/en/latest/


============
wagtailmenus
============

wagtailmenus is an extension for Torchbox's `Wagtail CMS <https://github.com/torchbox/wagtail>`_ to help you manage and render multi-level navigation and simple flat menus in a consistent, flexible way.

The current version is tested for compatibility with the following:

- Wagtail versions >4.1
- Python versions 3.7 to 3.11

.. image:: https://raw.githubusercontent.com/jazzband/wagtailmenus/master/docs/source/_static/images/repeating-item.png

New to wagtailmenus?
====================

Start by reading our `Overview and key concepts <http://wagtailmenus.readthedocs.io/en/stable/overview.html>`_ page.
It will give you a better understand of how the app works, and help you decide whether it is a good fit for your project.


How do I use it?
================

For everything you need to get up and running with wagtailmenus, `view the official documentation <http://wagtailmenus.readthedocs.io/>`_.


Contributing
============

Instructions on how to contribute to can be house `here <https://wagtailmenus.readthedocs.io/en/stable/contributing/index.html>`_.

As we are members of a `JazzBand project <https://jazzband.co/projects>`_, `wagtailmenus` contributors should adhere to the `Contributor Code of Conduct <https://jazzband.co/about/conduct>`_.
